@@ -19,14 +19,13 @@
  *
  * Author: Andy Hertzfeld <andy@eazel.com>
  *
- * $Id: ephy-spinner.h 12639 2006-12-12 17:06:55Z chpe $
+ * $Id: ephy-spinner.h 14182 2008-05-21 18:19:36Z awalton $
  */
 
 #ifndef EPHY_SPINNER_H
 #define EPHY_SPINNER_H
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkenums.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
