@@ -35,7 +35,7 @@
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-file.h>
-#include <gtk/gtkenums.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 enum {
