@@ -46,8 +46,7 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-mount-operation.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-icon-theme.h>
@@ -185,7 +184,7 @@ handle_go_back (NautilusNavigationWindow *window, GFile *location)
         GList *link;
         NautilusBookmark *bookmark;
 
-        g_return_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (window));
+        g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 
         /* Going back. Move items from the back list to the forward list. */
         g_assert (g_list_length (window->back_list) > NAUTILUS_WINDOW (window)->details->location_change_distance);
@@ -224,7 +223,7 @@ handle_go_forward (NautilusNavigationWindow *window, GFile *location)
         GList *link;
         NautilusBookmark *bookmark;
 
-        g_return_if_fail (NAUTILUS_IS_NAVIGATION_WINDOW (window));
+        g_assert (NAUTILUS_IS_NAVIGATION_WINDOW (window));
 
         /* Going forward. Move items from the forward list to the back list. */
         g_assert (g_list_length (window->forward_list) > NAUTILUS_WINDOW (window)->details->location_change_distance);
@@ -913,7 +912,6 @@ mount_not_mounted_callback (GObject *source_object,
 		window->details->mount_error = NULL;
 		g_error_free (error);
 	} else {
-		nautilus_inhibit_autorun_for_file (G_FILE (source_object));
 		nautilus_file_invalidate_all_attributes (window->details->determine_view_file);
 		nautilus_file_call_when_ready (window->details->determine_view_file,
 					       NAUTILUS_FILE_ATTRIBUTE_INFO |
@@ -1705,7 +1703,7 @@ display_view_selection_failure (NautilusWindow *window, NautilusFile *file,
 			error_message = g_strdup_printf (_("Could not display \"%s\"."),
 							 uri_for_display);
 			if (scheme_string != NULL) {
-				detail_message = g_strdup_printf (_("Nautilus cannot handle %s: locations."),
+				detail_message = g_strdup_printf (_("Nautilus cannot handle \"%s\" locations."),
 								  scheme_string);
 			} else {
 				detail_message = g_strdup (_("Nautilus cannot handle this kind of locations."));
